==> snortsms-0.14.9.tbz: www/snortsms/rules/dsp_view.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Rules");

include_once("../lib/func_Rules.php");
$rule = New Rule();



$row = $rsRule->fetchRow(DB_FETCHMODE_ASSOC);
$temp_sid = $row['sid'];
$temp_cat = $_REQUEST['FRM_cat'];
$temp_notes = preg_replace("/[\r\n]/","<BR>",$row['notes']);
/*** Load rule into object ***/
$rule->Parse($row['rule']);
$temp_rule = $rule->GenRule();
$temp_rev = $rule->GetOption("rev");
$temp_msg = $rule->GetOption("msg");
$temp_title = "Rule Details";




$content_lines=htmlspecialchars($rule->GetContentLines());
$content_lines=preg_replace("/\n/","<BR>",$content_lines );

$options_lines=htmlspecialchars($rule->GetOptionLines());
$options_lines=preg_replace("/\n/","<BR>",$options_lines );

$references_lines=htmlspecialchars($rule->GetReferenceLines());
$references_lines=preg_replace("/\n/","<BR>",$references_lines );
	

?>



<PRE>



</PRE>

<CENTER>

<table border="0" class="bg1" cellspacing="1" cellpadding="1">
<tr class="heading2" align="center">
<td><?=$temp_title?></TD>
</TR>
<tr><td>



<table border="0" cellspacing="4" class="bg2">
<tr>
<td colspan="2" align="right"><a href="index.php?fuseaction=rules.edit&FRM_sid=<?=$temp_sid?>&FRM_cat=<?=$temp_cat?>">[Edit Rule]</a></td>
</tr>

<td colspan="2">




<table border="0" class="bg2">
<tr>
<td class="label" valign="top" nowrap>Title</td><td class="bg4"><?=$temp_msg?></td>
</tr>
<tr>
<td class="label" valign="top">Catagory:</td><td class="bg4"><?=$temp_cat?></td>
</tr>
<tr>
<td class="label" valign="top">SID:</td><td class="bg4"><?=$temp_sid?></td>
</tr>
<tr>
<td class="label" valign="top">Revision:</td><td class="bg4"><?=$temp_rev?></td>
</tr>
<tr>
<th colspan="3">&nbsp;</th>
</tr>
</table>


</td>
</tr>
<tr>
<td valign="top">


<table border="0" class="bg2">
<tr>
<th class="bg5" colspan="3">Rule Headers</th>
</tr>
<tr>
<td class="label">Alert Action:</td><td class="bg4"><?=$rule->GetHeaderItem("action")?></td>
</tr>
<tr>
<td class="label">Protocol:</td><td class="bg4"><?=$rule->GetHeaderItem("protocol")?></td>
</tr>
<tr>
<td class="label">Source IP:</td><td class="bg4"><?=$rule->GetHeaderItem("src_ip")?></td>
</tr>
<tr>
<td class="label">Source Port:</td><td class="bg4"><?=$rule->GetHeaderItem("src_port")?></td>
</tr>
<tr>
<td class="label">Flow:</td><td class="bg4"><?=$rule->GetHeaderItem("flow")?></td>
</tr>
<tr>
<td class="label">Dest IP:</td><td class="bg4"><?=$rule->GetHeaderItem("dst_ip")?></td>
</tr>
<tr>
<td class="label">Dest Port:</td><td class="bg4"><?=$rule->GetHeaderItem("dst_port")?></td>
</tr>
</table>


</td><td valign="top">


<table border="0" class="bg2">
<tr>
<th class="bg5" colspan="3">Rule Options</th>
</tr>
<tr>
<td class="label" valign="top" nowrap>Content Directives:</td><td class="bg4"><?=$content_lines?></td>
</tr>
<tr>
<td class="label" valign="top">Directives:</td><td class="bg4"><?=$options_lines?></td>
</tr>
<tr>
<td class="label" valign="top">References:</td><td class="bg4"><?=$references_lines?></td>
</tr>

</table>





</td>
</tr>
<tr>
<th colspan="2" class="bg5">Rule Definition</th>
</tr>
<tr>
<td colspan="2" class="bg4"><?=$temp_rule?></td>
</tr>
<tr>
<tr>
<td colspan="2">&nbsp;</td>
</tr>


<tr>
<th colspan="2" class="bg5">Rule Notes</th>
</tr>
<tr>
<td colspan="2" class="bg4"><?=$temp_notes?>&nbsp;</td>
</tr>





<tr>
<td colspan="2">&nbsp;</td>
</tr>
<tr>
<td colspan="2" align="right"><a href="index.php?fuseaction=rules.edit&FRM_sid=<?=$temp_sid?>&FRM_cat=<?=$temp_cat?>">[Edit Rule]</a></td>
</tr>
</table>




</td>
</tr>
</TABLE>


</CENTER>

==> snortsms-1.0.0.tbz: www/snortsms/rules/dsp_view.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Rules");

include_once("../lib/func_Rules.php");
$rule = New Rule();



$row = $rsRule->fetchRow(DB_FETCHMODE_ASSOC);
$temp_sid = $row['sid'];
$temp_cat = $row['cata'];
$temp_notes = preg_replace("/[\r\n]/","<BR>",$row['notes']);
/*** Load rule into object ***/
$rule->Parse($row['rule']);
$temp_rule = $rule->GenRule();
$temp_rev = $rule->GetOption("rev");
$temp_msg = $rule->GetOption("msg");
$temp_title = "Rule Details";




$content_lines=htmlspecialchars($rule->GetContentLines());
$content_lines=preg_replace("/\n/","<BR>",$content_lines );

$options_lines=htmlspecialchars($rule->GetOptionLines());
$options_lines=preg_replace("/\n/","<BR>",$options_lines );

$references_lines=htmlspecialchars($rule->GetReferenceLines());
$references_lines=preg_replace("/\n/","<BR>",$references_lines );
	

?>



<PRE>



</PRE>

<CENTER>

<table border="0" class="bg1" cellspacing="1" cellpadding="1">
<tr class="heading2" align="center">
<td><?=$temp_title?></TD>
</TR>
<tr><td>



<table border="0" cellspacing="4" class="bg2">
<tr>
<td colspan="2" align="right"><a href="index.php?fuseaction=rules.edit&FRM_sid=<?=$temp_sid?>&FRM_cat=<?=$temp_cat?>">[Edit Rule]</a></td>
</tr>

<tr>
<td colspan="1">

<table border="0" class="bg2">
<tr>
<td class="label" valign="top" nowrap>Title:</td><td class="bg4"><?=$temp_msg?></td>
</tr>
<tr>
<td class="label" valign="top">Catagory:</td><td class="bg4"><?=$temp_cat?></td>
</tr>
<tr>
<td class="label" valign="top">SID:</td><td class="bg4"><?=$temp_sid?></td>
</tr>
<tr>
<td class="label" valign="top">Revision:</td><td class="bg4"><?=$temp_rev?></td>
</tr>
<tr>
<th colspan="3">&nbsp;</th>
</tr>
</table>

</td>



<td colspan="1" align="right" valign="top">

<table border="0" class="bg2">
<tr>
<td class="label" valign="top" nowrap>Assigned Profiles:</td><td class="bg4">
<?
while($row = $rsPlys->fetchRow(DB_FETCHMODE_ASSOC))
	{
	?>	
	<a href="index.php?fuseaction=policies.catagory&FRM_policyid=<?=$row["policyid"]?>&FRM_cat=<?=$temp_cat?>"><?=$row["name"]?></a> <BR>
	<?
	}
?>
&nbsp;
</td>
</tr>

<tr>
<th colspan="3">&nbsp;</th>
</tr>
</table>

</td>
</tr>



<tr>
<td valign="top">


<table border="0" class="bg2">
<tr>
<th class="bg5" colspan="3">Rule Headers</th>
</tr>
<tr>
<td class="label">Alert Action:</td><td class="bg4"><?=$rule->GetHeaderItem("action")?></td>
</tr>
<tr>
<td class="label">Protocol:</td><td class="bg4"><?=$rule->GetHeaderItem("protocol")?></td>
</tr>
<tr>
<td class="label">Source IP:</td><td class="bg4"><?=$rule->GetHeaderItem("src_ip")?></td>
</tr>
<tr>
<td class="label">Source Port:</td><td class="bg4"><?=$rule->GetHeaderItem("src_port")?></td>
</tr>
<tr>
<td class="label">Flow:</td><td class="bg4"><?=$rule->GetHeaderItem("flow")?></td>
</tr>
<tr>
<td class="label">Dest IP:</td><td class="bg4"><?=$rule->GetHeaderItem("dst_ip")?></td>
</tr>
<tr>
<td class="label">Dest Port:</td><td class="bg4"><?=$rule->GetHeaderItem("dst_port")?></td>
</tr>
</table>


</td><td valign="top">


<table border="0" class="bg2">
<tr>
<th class="bg5" colspan="3">Rule Options</th>
</tr>
<tr>
<td class="label" valign="top" nowrap>Content Directives:</td><td class="bg4"><?=$content_lines?></td>
</tr>
<tr>
<td class="label" valign="top">Directives:</td><td class="bg4"><?=$options_lines?></td>
</tr>
<tr>
<td class="label" valign="top">References:</td><td class="bg4"><?=$references_lines?></td>
</tr>

</table>





</td>
</tr>
<tr>
<th colspan="2" class="bg5">Rule Definition</th>
</tr>
<tr>
<td colspan="2" class="bg4"><?=$temp_rule?></td>
</tr>
<tr>
<tr>
<td colspan="2">&nbsp;</td>
</tr>


<tr>
<th colspan="2" class="bg5">Rule Notes</th>
</tr>
<tr>
<td colspan="2" class="bg4"><?=$temp_notes?>&nbsp;</td>
</tr>





<tr>
<td colspan="2">&nbsp;</td>
</tr>
<tr>
<td colspan="2" align="right"><a href="index.php?fuseaction=rules.edit&FRM_sid=<?=$temp_sid?>&FRM_cat=<?=$temp_cat?>">[Edit Rule]</a></td>
</tr>
</table>




</td>
</tr>
</TABLE>


</CENTER>
